Struct rusoto_workdocs::DescribeDocumentVersionsRequest
[−]
[src]
pub struct DescribeDocumentVersionsRequest {
pub authentication_token: Option<String>,
pub document_id: String,
pub fields: Option<String>,
pub include: Option<String>,
pub limit: Option<i64>,
pub marker: Option<String>,
}Fields
authentication_token: Option<String>
Amazon WorkDocs authentication token. This field should not be set when using administrative API actions, as in accessing the API using AWS credentials.
document_id: String
The ID of the document.
fields: Option<String>
Specify "SOURCE" to include initialized versions and a URL for the source document.
include: Option<String>
A comma-separated list of values. Specify "INITIALIZED" to include incomplete versions.
limit: Option<i64>
The maximum number of versions to return with this call.
marker: Option<String>
The marker for the next set of results. (You received this marker from a previous call.)